var searchData=
[
  ['libinput',['libinput',['../structlibinput.html',1,'']]],
  ['libinput_2eh',['libinput.h',['../libinput_8h.html',1,'']]],
  ['libinput_5fattribute_5fdeprecated',['LIBINPUT_ATTRIBUTE_DEPRECATED',['../libinput_8h.html#a765fe0783fd8cd83a82ecfe910780901',1,'libinput.h']]],
  ['libinput_5fattribute_5fprintf',['LIBINPUT_ATTRIBUTE_PRINTF',['../libinput_8h.html#a7de828556e8e12b23e4c5acec1581780',1,'libinput.h']]],
  ['libinput_5fbutton_5fstate',['libinput_button_state',['../group__device.html#ga543a8bb3f2d7421f76e63bb4ee2fb5bf',1,'libinput.h']]],
  ['libinput_5fbutton_5fstate_5fpressed',['LIBINPUT_BUTTON_STATE_PRESSED',['../group__device.html#gga543a8bb3f2d7421f76e63bb4ee2fb5bfa68b58fac43509a92230c315993dcf6b4',1,'libinput.h']]],
  ['libinput_5fbutton_5fstate_5freleased',['LIBINPUT_BUTTON_STATE_RELEASED',['../group__device.html#gga543a8bb3f2d7421f76e63bb4ee2fb5bfad20bd759a424b497d7d363ef136f856b',1,'libinput.h']]],
  ['libinput_5fconfig_5faccel_5fprofile',['libinput_config_accel_profile',['../group__config.html#gad63796972347f318b180e322e35cee79',1,'libinput.h']]],
  ['libinput_5fconfig_5faccel_5fprofile_5fadaptive',['LIBINPUT_CONFIG_ACCEL_PROFILE_ADAPTIVE',['../group__config.html#ggad63796972347f318b180e322e35cee79a7a68e3eaef381cb4c6b7a1439c4baa0c',1,'libinput.h']]],
  ['libinput_5fconfig_5faccel_5fprofile_5fflat',['LIBINPUT_CONFIG_ACCEL_PROFILE_FLAT',['../group__config.html#ggad63796972347f318b180e322e35cee79a9b9cfc7fe60f204d88d0ae25e928566b',1,'libinput.h']]],
  ['libinput_5fconfig_5faccel_5fprofile_5fnone',['LIBINPUT_CONFIG_ACCEL_PROFILE_NONE',['../group__config.html#ggad63796972347f318b180e322e35cee79ae11b64047b82d1ae6de22753873ee8ad',1,'libinput.h']]],
  ['libinput_5fconfig_5fclick_5fmethod',['libinput_config_click_method',['../group__config.html#ga3e5dc19a83752430d5e8be7fb2020663',1,'libinput.h']]],
  ['libinput_5fconfig_5fclick_5fmethod_5fbutton_5fareas',['LIBINPUT_CONFIG_CLICK_METHOD_BUTTON_AREAS',['../group__config.html#gga3e5dc19a83752430d5e8be7fb2020663ab8ce100b5396698712579447b6d2e173',1,'libinput.h']]],
  ['libinput_5fconfig_5fclick_5fmethod_5fclickfinger',['LIBINPUT_CONFIG_CLICK_METHOD_CLICKFINGER',['../group__config.html#gga3e5dc19a83752430d5e8be7fb2020663af81af7bdec6f0f797abf6d68f294d276',1,'libinput.h']]],
  ['libinput_5fconfig_5fclick_5fmethod_5fnone',['LIBINPUT_CONFIG_CLICK_METHOD_NONE',['../group__config.html#gga3e5dc19a83752430d5e8be7fb2020663a44f53f91f3b24a6d41ae9b04420ab374',1,'libinput.h']]],
  ['libinput_5fconfig_5fdrag_5fdisabled',['LIBINPUT_CONFIG_DRAG_DISABLED',['../group__config.html#ggaddca1d98dbf1b53fc93de3d323588423a8c01d046cb2229408b969a25207f7878',1,'libinput.h']]],
  ['libinput_5fconfig_5fdrag_5fenabled',['LIBINPUT_CONFIG_DRAG_ENABLED',['../group__config.html#ggaddca1d98dbf1b53fc93de3d323588423a1ab4787df6f5f16b681ca5d741b0f87f',1,'libinput.h']]],
  ['libinput_5fconfig_5fdrag_5flock_5fdisabled',['LIBINPUT_CONFIG_DRAG_LOCK_DISABLED',['../group__config.html#ggaedaabeb8e33f58a032c2e099b91f4579aeecd18dcf22efe84126b0374a9e377f9',1,'libinput.h']]],
  ['libinput_5fconfig_5fdrag_5flock_5fenabled',['LIBINPUT_CONFIG_DRAG_LOCK_ENABLED',['../group__config.html#ggaedaabeb8e33f58a032c2e099b91f4579a5f2fe7ed93c6aa7cd4a8edec35a7d790',1,'libinput.h']]],
  ['libinput_5fconfig_5fdrag_5flock_5fstate',['libinput_config_drag_lock_state',['../group__config.html#gaedaabeb8e33f58a032c2e099b91f4579',1,'libinput.h']]],
  ['libinput_5fconfig_5fdrag_5fstate',['libinput_config_drag_state',['../group__config.html#gaddca1d98dbf1b53fc93de3d323588423',1,'libinput.h']]],
  ['libinput_5fconfig_5fdwt_5fdisabled',['LIBINPUT_CONFIG_DWT_DISABLED',['../group__config.html#ggacf6846753a607f830ebbd0d3d181f813aa2bc02fbd8904cd0b69c05db91aa5500',1,'libinput.h']]],
  ['libinput_5fconfig_5fdwt_5fenabled',['LIBINPUT_CONFIG_DWT_ENABLED',['../group__config.html#ggacf6846753a607f830ebbd0d3d181f813ac45dae5f37cade37896b159526e75bf7',1,'libinput.h']]],
  ['libinput_5fconfig_5fdwt_5fstate',['libinput_config_dwt_state',['../group__config.html#gacf6846753a607f830ebbd0d3d181f813',1,'libinput.h']]],
  ['libinput_5fconfig_5fmiddle_5femulation_5fdisabled',['LIBINPUT_CONFIG_MIDDLE_EMULATION_DISABLED',['../group__config.html#gga43d9b6271fdbf41b3a0591dea9d1b86aa27d0a42a0f837cf14e7fc3e4995d3c6c',1,'libinput.h']]],
  ['libinput_5fconfig_5fmiddle_5femulation_5fenabled',['LIBINPUT_CONFIG_MIDDLE_EMULATION_ENABLED',['../group__config.html#gga43d9b6271fdbf41b3a0591dea9d1b86aa9befdeb099345c78fc0e69ff3b93dbb5',1,'libinput.h']]],
  ['libinput_5fconfig_5fmiddle_5femulation_5fstate',['libinput_config_middle_emulation_state',['../group__config.html#ga43d9b6271fdbf41b3a0591dea9d1b86a',1,'libinput.h']]],
  ['libinput_5fconfig_5fscroll_5f2fg',['LIBINPUT_CONFIG_SCROLL_2FG',['../group__config.html#gga6466e6b9c55e6835a05c7c29c8b7a844aaa2f1aa2d40a3e64129ae4bc3ebac026',1,'libinput.h']]],
  ['libinput_5fconfig_5fscroll_5fedge',['LIBINPUT_CONFIG_SCROLL_EDGE',['../group__config.html#gga6466e6b9c55e6835a05c7c29c8b7a844a294ce3d2e42044573a5eaad2b3cf8983',1,'libinput.h']]],
  ['libinput_5fconfig_5fscroll_5fmethod',['libinput_config_scroll_method',['../group__config.html#ga6466e6b9c55e6835a05c7c29c8b7a844',1,'libinput.h']]],
  ['libinput_5fconfig_5fscroll_5fno_5fscroll',['LIBINPUT_CONFIG_SCROLL_NO_SCROLL',['../group__config.html#gga6466e6b9c55e6835a05c7c29c8b7a844ab7b4cad9341e40ef343ca174a997381b',1,'libinput.h']]],
  ['libinput_5fconfig_5fscroll_5fon_5fbutton_5fdown',['LIBINPUT_CONFIG_SCROLL_ON_BUTTON_DOWN',['../group__config.html#gga6466e6b9c55e6835a05c7c29c8b7a844aa847f5e170a3d9fb377880bf836d9c43',1,'libinput.h']]],
  ['libinput_5fconfig_5fsend_5fevents_5fdisabled',['LIBINPUT_CONFIG_SEND_EVENTS_DISABLED',['../group__config.html#gga56c9886b0161ecdb9b351d8dedc212e4ab9561f6f22974f70fd31aae25a86526f',1,'libinput.h']]],
  ['libinput_5fconfig_5fsend_5fevents_5fdisabled_5fon_5fexternal_5fmouse',['LIBINPUT_CONFIG_SEND_EVENTS_DISABLED_ON_EXTERNAL_MOUSE',['../group__config.html#gga56c9886b0161ecdb9b351d8dedc212e4acf20fe4b46ccd5b1b1c4721f630e4f64',1,'libinput.h']]],
  ['libinput_5fconfig_5fsend_5fevents_5fenabled',['LIBINPUT_CONFIG_SEND_EVENTS_ENABLED',['../group__config.html#gga56c9886b0161ecdb9b351d8dedc212e4aadc80683fe80670f2cdab0234011302d',1,'libinput.h']]],
  ['libinput_5fconfig_5fsend_5fevents_5fmode',['libinput_config_send_events_mode',['../group__config.html#ga56c9886b0161ecdb9b351d8dedc212e4',1,'libinput.h']]],
  ['libinput_5fconfig_5fstatus',['libinput_config_status',['../group__config.html#ga33ff306ed8505129adce4c092a3ed175',1,'libinput.h']]],
  ['libinput_5fconfig_5fstatus_5finvalid',['LIBINPUT_CONFIG_STATUS_INVALID',['../group__config.html#gga33ff306ed8505129adce4c092a3ed175abb7bb2e5f6d7ce182d5e7bd546f5442c',1,'libinput.h']]],
  ['libinput_5fconfig_5fstatus_5fsuccess',['LIBINPUT_CONFIG_STATUS_SUCCESS',['../group__config.html#gga33ff306ed8505129adce4c092a3ed175a59345d3cb7b87a73ea505f847d0cbdb2',1,'libinput.h']]],
  ['libinput_5fconfig_5fstatus_5fto_5fstr',['libinput_config_status_to_str',['../group__config.html#ga7eee5ba99988d80bb9dd744894c72e06',1,'libinput.h']]],
  ['libinput_5fconfig_5fstatus_5funsupported',['LIBINPUT_CONFIG_STATUS_UNSUPPORTED',['../group__config.html#gga33ff306ed8505129adce4c092a3ed175a54cb4059494ad0d6b305d8bdeb4d6d22',1,'libinput.h']]],
  ['libinput_5fconfig_5ftap_5fdisabled',['LIBINPUT_CONFIG_TAP_DISABLED',['../group__config.html#ggaca4a3177736e6fd024cb77bc684857a1ab202825f96206e91e8faa8c379b81b11',1,'libinput.h']]],
  ['libinput_5fconfig_5ftap_5fenabled',['LIBINPUT_CONFIG_TAP_ENABLED',['../group__config.html#ggaca4a3177736e6fd024cb77bc684857a1ab3cb0b659d23d21b0b55c676899af92a',1,'libinput.h']]],
  ['libinput_5fconfig_5ftap_5fstate',['libinput_config_tap_state',['../group__config.html#gaca4a3177736e6fd024cb77bc684857a1',1,'libinput.h']]],
  ['libinput_5fdevice',['libinput_device',['../structlibinput__device.html',1,'']]],
  ['libinput_5fdevice_5fcap_5fgesture',['LIBINPUT_DEVICE_CAP_GESTURE',['../group__device.html#gga3110cdddce94a1df0b8a3306909c8f15a592711b6976e0dab448a1ad8f412d527',1,'libinput.h']]],
  ['libinput_5fdevice_5fcap_5fkeyboard',['LIBINPUT_DEVICE_CAP_KEYBOARD',['../group__device.html#gga3110cdddce94a1df0b8a3306909c8f15a733315d968cac7bd569b43b71664ae4b',1,'libinput.h']]],
  ['libinput_5fdevice_5fcap_5fpointer',['LIBINPUT_DEVICE_CAP_POINTER',['../group__device.html#gga3110cdddce94a1df0b8a3306909c8f15a6e7c3249a8f0503fce7e0a5effc4d73f',1,'libinput.h']]],
  ['libinput_5fdevice_5fcap_5ftablet_5fpad',['LIBINPUT_DEVICE_CAP_TABLET_PAD',['../group__device.html#gga3110cdddce94a1df0b8a3306909c8f15a98ec191d1a685df5cdf87a19b2ee9a9f',1,'libinput.h']]],
  ['libinput_5fdevice_5fcap_5ftablet_5ftool',['LIBINPUT_DEVICE_CAP_TABLET_TOOL',['../group__device.html#gga3110cdddce94a1df0b8a3306909c8f15ad3eafb7274a330c5839f00030850db6d',1,'libinput.h']]],
  ['libinput_5fdevice_5fcap_5ftouch',['LIBINPUT_DEVICE_CAP_TOUCH',['../group__device.html#gga3110cdddce94a1df0b8a3306909c8f15aad61f92a8154c9017d4e621c768712aa',1,'libinput.h']]],
  ['libinput_5fdevice_5fcapability',['libinput_device_capability',['../group__device.html#ga3110cdddce94a1df0b8a3306909c8f15',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5faccel_5fget_5fdefault_5fprofile',['libinput_device_config_accel_get_default_profile',['../group__config.html#ga288b904c2c0dcc188e3522291ab997c9',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5faccel_5fget_5fdefault_5fspeed',['libinput_device_config_accel_get_default_speed',['../group__config.html#ga71fba19df9d2cb15904c6351cec1af35',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5faccel_5fget_5fprofile',['libinput_device_config_accel_get_profile',['../group__config.html#ga7f61a24d32878b0e8124695c10adef8f',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5faccel_5fget_5fprofiles',['libinput_device_config_accel_get_profiles',['../group__config.html#gac2c57d3f082233b2cea696c8dbffee43',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5faccel_5fget_5fspeed',['libinput_device_config_accel_get_speed',['../group__config.html#gaac7c1b31e0131154d31b9167c876cc3b',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5faccel_5fis_5favailable',['libinput_device_config_accel_is_available',['../group__config.html#ga77b20c16fe26f385936f1d8cb4a1a560',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5faccel_5fset_5fprofile',['libinput_device_config_accel_set_profile',['../group__config.html#ga6e72a6214840d76c8a43d3753c1d549d',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5faccel_5fset_5fspeed',['libinput_device_config_accel_set_speed',['../group__config.html#ga1d9761bb99b445524fb2ea801f946ef1',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fcalibration_5fget_5fdefault_5fmatrix',['libinput_device_config_calibration_get_default_matrix',['../group__config.html#ga3d9f1b9be10e804e170c4ea455bd1f1b',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fcalibration_5fget_5fmatrix',['libinput_device_config_calibration_get_matrix',['../group__config.html#gaa16e8b272ce94f8037822dc8c89d84a5',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fcalibration_5fhas_5fmatrix',['libinput_device_config_calibration_has_matrix',['../group__config.html#gadd921b0caef6fcf05199a93e5ee0728b',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fcalibration_5fset_5fmatrix',['libinput_device_config_calibration_set_matrix',['../group__config.html#ga09a798f58cc601edd2797780096e9804',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fclick_5fget_5fdefault_5fmethod',['libinput_device_config_click_get_default_method',['../group__config.html#ga574f5bce37a87b6e05a956481748e9b4',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fclick_5fget_5fmethod',['libinput_device_config_click_get_method',['../group__config.html#ga6aa5fc908b050beb6c0346a09478cad4',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fclick_5fget_5fmethods',['libinput_device_config_click_get_methods',['../group__config.html#ga30f433d7c21fc8e65dd218079ce1a2a9',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fclick_5fset_5fmethod',['libinput_device_config_click_set_method',['../group__config.html#gadfd0d6c30f8d87ae570c9159953de3c9',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fdwt_5fget_5fdefault_5fenabled',['libinput_device_config_dwt_get_default_enabled',['../group__config.html#ga4b386261e05d2a89973148e9ce56731e',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fdwt_5fget_5fenabled',['libinput_device_config_dwt_get_enabled',['../group__config.html#gaf350c6505b5736ec410878b5daf28142',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fdwt_5fis_5favailable',['libinput_device_config_dwt_is_available',['../group__config.html#ga0d440dd9a15b10784d3a72fb8086fd32',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fdwt_5fset_5fenabled',['libinput_device_config_dwt_set_enabled',['../group__config.html#ga5e30865097b8fa273c3e3cbcdff51b0f',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fleft_5fhanded_5fget',['libinput_device_config_left_handed_get',['../group__config.html#ga998945b1c4f96a9abd3c3a26e5c4166c',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fleft_5fhanded_5fget_5fdefault',['libinput_device_config_left_handed_get_default',['../group__config.html#gaa438a14e32894791e435cb43826ef3a9',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fleft_5fhanded_5fis_5favailable',['libinput_device_config_left_handed_is_available',['../group__config.html#ga755352f2bbb869446aa591dd9d9c5eaf',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fleft_5fhanded_5fset',['libinput_device_config_left_handed_set',['../group__config.html#ga9bbdef04c07804ce7c121133c04d4edf',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fmiddle_5femulation_5fget_5fdefault_5fenabled',['libinput_device_config_middle_emulation_get_default_enabled',['../group__config.html#ga602bf0edd3553972cd2d1f841401578b',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fmiddle_5femulation_5fget_5fenabled',['libinput_device_config_middle_emulation_get_enabled',['../group__config.html#ga4669a9e2eeda7ddd648d340935c40ada',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fmiddle_5femulation_5fis_5favailable',['libinput_device_config_middle_emulation_is_available',['../group__config.html#gad9d32f1fd776fa112e5eaac6419de6b7',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fmiddle_5femulation_5fset_5fenabled',['libinput_device_config_middle_emulation_set_enabled',['../group__config.html#ga584d862a116fb0a26cc95304f8c13eb1',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5frotation_5fget_5fangle',['libinput_device_config_rotation_get_angle',['../group__config.html#gaf57b8746f6f56d2410aa71f29416c9a2',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5frotation_5fget_5fdefault_5fangle',['libinput_device_config_rotation_get_default_angle',['../group__config.html#ga820ae96544109707d3bfef41a6114ea7',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5frotation_5fis_5favailable',['libinput_device_config_rotation_is_available',['../group__config.html#ga2fab82b2ba0cac9a645c1ce8e32df448',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5frotation_5fset_5fangle',['libinput_device_config_rotation_set_angle',['../group__config.html#ga136b2f7753235c5d2a9fb2762a040eef',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fscroll_5fget_5fbutton',['libinput_device_config_scroll_get_button',['../group__config.html#ga83623da437d0114b8e3ac29ab771d799',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fscroll_5fget_5fdefault_5fbutton',['libinput_device_config_scroll_get_default_button',['../group__config.html#gad4aacefb10fab1e401e211ee9ce0c1e6',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fscroll_5fget_5fdefault_5fmethod',['libinput_device_config_scroll_get_default_method',['../group__config.html#ga844ea06b952aaee8e0643d85d351afb6',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fscroll_5fget_5fdefault_5fnatural_5fscroll_5fenabled',['libinput_device_config_scroll_get_default_natural_scroll_enabled',['../group__config.html#gaab8cf4106f5836bf92038414b33b3bc3',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fscroll_5fget_5fmethod',['libinput_device_config_scroll_get_method',['../group__config.html#ga4bc3cc3822eea632a9a6cf3760ea1fd0',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fscroll_5fget_5fmethods',['libinput_device_config_scroll_get_methods',['../group__config.html#gacaad48862a67ca61cb8e257a7e80ee8c',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fscroll_5fget_5fnatural_5fscroll_5fenabled',['libinput_device_config_scroll_get_natural_scroll_enabled',['../group__config.html#gab4074b193c4350597d2221c4c34c0d15',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fscroll_5fhas_5fnatural_5fscroll',['libinput_device_config_scroll_has_natural_scroll',['../group__config.html#ga82d1aa961d2bb2f0c72c22e2441a4fc3',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fscroll_5fset_5fbutton',['libinput_device_config_scroll_set_button',['../group__config.html#gac95a25055b22c3631e3c10c0463ca332',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fscroll_5fset_5fmethod',['libinput_device_config_scroll_set_method',['../group__config.html#ga482951a2b1faf837e43d30d9c92dc9d3',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fscroll_5fset_5fnatural_5fscroll_5fenabled',['libinput_device_config_scroll_set_natural_scroll_enabled',['../group__config.html#ga958b67193c3948b59add719a68f1b948',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fsend_5fevents_5fget_5fdefault_5fmode',['libinput_device_config_send_events_get_default_mode',['../group__config.html#gaef671857791fcc889f609f6db96f2fe6',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fsend_5fevents_5fget_5fmode',['libinput_device_config_send_events_get_mode',['../group__config.html#gae945f2120764570f0b7c48b69a035543',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fsend_5fevents_5fget_5fmodes',['libinput_device_config_send_events_get_modes',['../group__config.html#gaa03e5c609b0b199402048fcd2cf85b24',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fsend_5fevents_5fset_5fmode',['libinput_device_config_send_events_set_mode',['../group__config.html#gaacc79635146b888ddaf1cb35363b22ce',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5ftap_5fget_5fdefault_5fdrag_5fenabled',['libinput_device_config_tap_get_default_drag_enabled',['../group__config.html#ga1c67925fe57210fc34ee0fa07b8e051a',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5ftap_5fget_5fdefault_5fdrag_5flock_5fenabled',['libinput_device_config_tap_get_default_drag_lock_enabled',['../group__config.html#gaa9ac23a944aa2232397bcd856cc55055',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5ftap_5fget_5fdefault_5fenabled',['libinput_device_config_tap_get_default_enabled',['../group__config.html#gaf6906b7344ee8d446594de08b4d065be',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5ftap_5fget_5fdrag_5fenabled',['libinput_device_config_tap_get_drag_enabled',['../group__config.html#gab75b1a0a6864c8916b13bfced9acc665',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5ftap_5fget_5fdrag_5flock_5fenabled',['libinput_device_config_tap_get_drag_lock_enabled',['../group__config.html#ga096a8960db3d6e43c419180270755584',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5ftap_5fget_5fenabled',['libinput_device_config_tap_get_enabled',['../group__config.html#ga8bfe1d541dcadaedeedcd7a98d5b7e07',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5ftap_5fget_5ffinger_5fcount',['libinput_device_config_tap_get_finger_count',['../group__config.html#ga13973d6bd75a99708723e3c6684517c1',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5ftap_5fset_5fdrag_5fenabled',['libinput_device_config_tap_set_drag_enabled',['../group__config.html#gad4416f89e0a709005854826affd014d9',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5ftap_5fset_5fdrag_5flock_5fenabled',['libinput_device_config_tap_set_drag_lock_enabled',['../group__config.html#ga8b72d649a4e05a455c1d0ec4194cb755',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5ftap_5fset_5fenabled',['libinput_device_config_tap_set_enabled',['../group__config.html#ga3caf860883d4e2e42b7842599da03e56',1,'libinput.h']]],
  ['libinput_5fdevice_5fget_5fcontext',['libinput_device_get_context',['../group__device.html#ga90c6868911d8aba103278c9208d5205e',1,'libinput.h']]],
  ['libinput_5fdevice_5fget_5fdevice_5fgroup',['libinput_device_get_device_group',['../group__device.html#ga0edc58e5a022b48a8d8416f63d2860df',1,'libinput.h']]],
  ['libinput_5fdevice_5fget_5fid_5fproduct',['libinput_device_get_id_product',['../group__device.html#gae011910b4a673f1293a20a84be4e52e2',1,'libinput.h']]],
  ['libinput_5fdevice_5fget_5fid_5fvendor',['libinput_device_get_id_vendor',['../group__device.html#gad9e4c074b03da790de5e117c71ce8d50',1,'libinput.h']]],
  ['libinput_5fdevice_5fget_5fname',['libinput_device_get_name',['../group__device.html#ga31655d2c2f173d059b3f891801c0a429',1,'libinput.h']]],
  ['libinput_5fdevice_5fget_5foutput_5fname',['libinput_device_get_output_name',['../group__device.html#gaf48626f6190e9c9bc14abb704e66cc22',1,'libinput.h']]],
  ['libinput_5fdevice_5fget_5fseat',['libinput_device_get_seat',['../group__device.html#ga27823edb40750992a1a05e7a9f5dc8f0',1,'libinput.h']]],
  ['libinput_5fdevice_5fget_5fsize',['libinput_device_get_size',['../group__device.html#gab91ae9014902fafe4f015e1f42233d27',1,'libinput.h']]],
  ['libinput_5fdevice_5fget_5fsysname',['libinput_device_get_sysname',['../group__device.html#ga106bbe58e6c3a6d1327c9bcbbf2a03f6',1,'libinput.h']]],
  ['libinput_5fdevice_5fget_5fudev_5fdevice',['libinput_device_get_udev_device',['../group__device.html#gaedc690c6679f547c46d9f41182a0e7c9',1,'libinput.h']]],
  ['libinput_5fdevice_5fget_5fuser_5fdata',['libinput_device_get_user_data',['../group__device.html#gaf5c902f56206a5d441e50c3a95ec458b',1,'libinput.h']]],
  ['libinput_5fdevice_5fgroup',['libinput_device_group',['../structlibinput__device__group.html',1,'']]],
  ['libinput_5fdevice_5fgroup_5fget_5fuser_5fdata',['libinput_device_group_get_user_data',['../group__device.html#ga779d66e502b17a4c4aae6d3c773470f9',1,'libinput.h']]],
  ['libinput_5fdevice_5fgroup_5fref',['libinput_device_group_ref',['../group__device.html#ga72f2803f681e074e56e0da63e4ccead2',1,'libinput.h']]],
  ['libinput_5fdevice_5fgroup_5fset_5fuser_5fdata',['libinput_device_group_set_user_data',['../group__device.html#gaf252f7535939d813ebe6eb7b2b792446',1,'libinput.h']]],
  ['libinput_5fdevice_5fgroup_5funref',['libinput_device_group_unref',['../group__device.html#ga371124d3d3bec0a7f946acd1c4417efe',1,'libinput.h']]],
  ['libinput_5fdevice_5fhas_5fcapability',['libinput_device_has_capability',['../group__device.html#gaa32d887454e8baf8aaeeb635329aef89',1,'libinput.h']]],
  ['libinput_5fdevice_5fkeyboard_5fhas_5fkey',['libinput_device_keyboard_has_key',['../group__device.html#ga80efc6bbab881c6785f0184ddc97c5ce',1,'libinput.h']]],
  ['libinput_5fdevice_5fled_5fupdate',['libinput_device_led_update',['../group__device.html#gafdb3ddfb91e6bd38b6356a5bb51547ad',1,'libinput.h']]],
  ['libinput_5fdevice_5fpointer_5fhas_5fbutton',['libinput_device_pointer_has_button',['../group__device.html#gaaf63f10e5120daf174bd7943169f45bf',1,'libinput.h']]],
  ['libinput_5fdevice_5fref',['libinput_device_ref',['../group__device.html#ga3335d55a50f0c2fb0c5f496a3105d467',1,'libinput.h']]],
  ['libinput_5fdevice_5fset_5fseat_5flogical_5fname',['libinput_device_set_seat_logical_name',['../group__device.html#ga9f76acc43c8684a13f232073ee829b50',1,'libinput.h']]],
  ['libinput_5fdevice_5fset_5fuser_5fdata',['libinput_device_set_user_data',['../group__device.html#ga6243ad6005b2ce2a5ecfd1b04787fe93',1,'libinput.h']]],
  ['libinput_5fdevice_5ftablet_5fpad_5fget_5fmode_5fgroup',['libinput_device_tablet_pad_get_mode_group',['../group__tablet__pad__modes.html#ga6260a3ec1a1ba152dcf7eed18c8a154b',1,'libinput.h']]],
  ['libinput_5fdevice_5ftablet_5fpad_5fget_5fnum_5fbuttons',['libinput_device_tablet_pad_get_num_buttons',['../group__device.html#ga2c5a5703982bcedc71a0470278258710',1,'libinput.h']]],
  ['libinput_5fdevice_5ftablet_5fpad_5fget_5fnum_5fmode_5fgroups',['libinput_device_tablet_pad_get_num_mode_groups',['../group__tablet__pad__modes.html#ga4d246393e68fd7c415a6936c92a23643',1,'libinput.h']]],
  ['libinput_5fdevice_5ftablet_5fpad_5fget_5fnum_5frings',['libinput_device_tablet_pad_get_num_rings',['../group__device.html#ga624cd4cb5fcd049fe88b2ab5f0a649cb',1,'libinput.h']]],
  ['libinput_5fdevice_5ftablet_5fpad_5fget_5fnum_5fstrips',['libinput_device_tablet_pad_get_num_strips',['../group__device.html#gaa0696b32b500ccc0876396a184e22c01',1,'libinput.h']]],
  ['libinput_5fdevice_5funref',['libinput_device_unref',['../group__device.html#ga857340e2dab06c7f7d84173a5a1fa427',1,'libinput.h']]],
  ['libinput_5fdispatch',['libinput_dispatch',['../group__base.html#ga271f910ed17461830e48d4cd20483a00',1,'libinput.h']]],
  ['libinput_5fevent',['libinput_event',['../structlibinput__event.html',1,'']]],
  ['libinput_5fevent_5fdestroy',['libinput_event_destroy',['../group__event.html#ga1df956c16e26cbbd911e553ec081022a',1,'libinput.h']]],
  ['libinput_5fevent_5fdevice_5fadded',['LIBINPUT_EVENT_DEVICE_ADDED',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca4da18343b29cc16ae2df09b9a3bff33b',1,'libinput.h']]],
  ['libinput_5fevent_5fdevice_5fnotify',['libinput_event_device_notify',['../structlibinput__event__device__notify.html',1,'']]],
  ['libinput_5fevent_5fdevice_5fnotify_5fget_5fbase_5fevent',['libinput_event_device_notify_get_base_event',['../group__event.html#ga19d329b7685c3a994718cec3845db1a0',1,'libinput.h']]],
  ['libinput_5fevent_5fdevice_5fremoved',['LIBINPUT_EVENT_DEVICE_REMOVED',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca971332bb0efebbfb240001466684dd09',1,'libinput.h']]],
  ['libinput_5fevent_5fgesture_5fget_5fangle_5fdelta',['libinput_event_gesture_get_angle_delta',['../group__event__gesture.html#ga53ed099f051922a765f8e614d96a0fea',1,'libinput.h']]],
  ['libinput_5fevent_5fgesture_5fget_5fbase_5fevent',['libinput_event_gesture_get_base_event',['../group__event__gesture.html#gab46fd1f8b4d5e12bc4d365e3599dfc94',1,'libinput.h']]],
  ['libinput_5fevent_5fgesture_5fget_5fcancelled',['libinput_event_gesture_get_cancelled',['../group__event__gesture.html#ga797bdfac0367cea193fac960258bbcb8',1,'libinput.h']]],
  ['libinput_5fevent_5fgesture_5fget_5fdx',['libinput_event_gesture_get_dx',['../group__event__gesture.html#ga3888052854155ad133fa837e4f28d771',1,'libinput.h']]],
  ['libinput_5fevent_5fgesture_5fget_5fdx_5funaccelerated',['libinput_event_gesture_get_dx_unaccelerated',['../group__event__gesture.html#ga9220d6e748fada925665cf9075e3812a',1,'libinput.h']]],
  ['libinput_5fevent_5fgesture_5fget_5fdy',['libinput_event_gesture_get_dy',['../group__event__gesture.html#gabcaa25a116f982acce8d98c0290ef6a2',1,'libinput.h']]],
  ['libinput_5fevent_5fgesture_5fget_5fdy_5funaccelerated',['libinput_event_gesture_get_dy_unaccelerated',['../group__event__gesture.html#ga52acb898a13ca5e638cd77cdf5983362',1,'libinput.h']]],
  ['libinput_5fevent_5fgesture_5fget_5ffinger_5fcount',['libinput_event_gesture_get_finger_count',['../group__event__gesture.html#gacc6909a8adb6992da9cf2638d332e009',1,'libinput.h']]],
  ['libinput_5fevent_5fgesture_5fget_5fscale',['libinput_event_gesture_get_scale',['../group__event__gesture.html#ga946ad3a4d60e728e89e13a6066b59a20',1,'libinput.h']]],
  ['libinput_5fevent_5fgesture_5fget_5ftime',['libinput_event_gesture_get_time',['../group__event__gesture.html#ga6cdd8a884a49e323d9691bde058c5e4e',1,'libinput.h']]],
  ['libinput_5fevent_5fgesture_5fget_5ftime_5fusec',['libinput_event_gesture_get_time_usec',['../group__event__gesture.html#ga0c281ad149d3f5e90e96c3073d82765a',1,'libinput.h']]],
  ['libinput_5fevent_5fgesture_5fpinch_5fbegin',['LIBINPUT_EVENT_GESTURE_PINCH_BEGIN',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7cae431f9d5995d1ad62154454000e7fae0',1,'libinput.h']]],
  ['libinput_5fevent_5fgesture_5fpinch_5fend',['LIBINPUT_EVENT_GESTURE_PINCH_END',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca9aa7b3d9e5801fe356a1b8b5ef42216c',1,'libinput.h']]],
  ['libinput_5fevent_5fgesture_5fpinch_5fupdate',['LIBINPUT_EVENT_GESTURE_PINCH_UPDATE',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7cadc7310d99139bb0b1f19fb72358d31dc',1,'libinput.h']]],
  ['libinput_5fevent_5fgesture_5fswipe_5fbegin',['LIBINPUT_EVENT_GESTURE_SWIPE_BEGIN',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca6a12d78aa41a5e03daeb60bfc8a540d9',1,'libinput.h']]],
  ['libinput_5fevent_5fgesture_5fswipe_5fend',['LIBINPUT_EVENT_GESTURE_SWIPE_END',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca0f8de0891bfb23805bedf93c32e1dcb6',1,'libinput.h']]],
  ['libinput_5fevent_5fgesture_5fswipe_5fupdate',['LIBINPUT_EVENT_GESTURE_SWIPE_UPDATE',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7caadbcbf32ccc89daf92197a4d205b213d',1,'libinput.h']]],
  ['libinput_5fevent_5fget_5fcontext',['libinput_event_get_context',['../group__event.html#ga28557ae0295f61c45f9b6e4ff7f86632',1,'libinput.h']]],
  ['libinput_5fevent_5fget_5fdevice',['libinput_event_get_device',['../group__event.html#ga8a49a089181960f7536344f7637ea777',1,'libinput.h']]],
  ['libinput_5fevent_5fget_5fdevice_5fnotify_5fevent',['libinput_event_get_device_notify_event',['../group__event.html#ga2bbc1391a3397d57d37ae3e2f8175abc',1,'libinput.h']]],
  ['libinput_5fevent_5fget_5fgesture_5fevent',['libinput_event_get_gesture_event',['../group__event.html#gae173f30b70c265036bbdc9557f3115c4',1,'libinput.h']]],
  ['libinput_5fevent_5fget_5fkeyboard_5fevent',['libinput_event_get_keyboard_event',['../group__event.html#ga8378f8fdd01e8afbcea8ddbb5411570d',1,'libinput.h']]],
  ['libinput_5fevent_5fget_5fpointer_5fevent',['libinput_event_get_pointer_event',['../group__event.html#ga52acdc3afcf75efeb8153f50eef20615',1,'libinput.h']]],
  ['libinput_5fevent_5fget_5ftablet_5fpad_5fevent',['libinput_event_get_tablet_pad_event',['../group__event.html#gaf5677182e32138bda352cc37b03dec07',1,'libinput.h']]],
  ['libinput_5fevent_5fget_5ftablet_5ftool_5fevent',['libinput_event_get_tablet_tool_event',['../group__event.html#gadfd7d9f1c3210f394faa60928f3c187f',1,'libinput.h']]],
  ['libinput_5fevent_5fget_5ftouch_5fevent',['libinput_event_get_touch_event',['../group__event.html#gad2cba8252024bdcc341499bedd3d0be7',1,'libinput.h']]],
  ['libinput_5fevent_5fget_5ftype',['libinput_event_get_type',['../group__event.html#ga430a3a7369afd6c5ff722179327df79a',1,'libinput.h']]],
  ['libinput_5fevent_5fkeyboard',['libinput_event_keyboard',['../structlibinput__event__keyboard.html',1,'']]],
  ['libinput_5fevent_5fkeyboard_5fget_5fbase_5fevent',['libinput_event_keyboard_get_base_event',['../group__event__keyboard.html#gae5a3b7e12e7e8b213b3da92a13adb88d',1,'libinput.h']]],
  ['libinput_5fevent_5fkeyboard_5fget_5fkey',['libinput_event_keyboard_get_key',['../group__event__keyboard.html#gad29cc9f276d9468463d01f65ccf8deaf',1,'libinput.h']]],
  ['libinput_5fevent_5fkeyboard_5fget_5fkey_5fstate',['libinput_event_keyboard_get_key_state',['../group__event__keyboard.html#gaf7b018edbc264ba81a2d475d42ebbd98',1,'libinput.h']]],
  ['libinput_5fevent_5fkeyboard_5fget_5fseat_5fkey_5fcount',['libinput_event_keyboard_get_seat_key_count',['../group__event__keyboard.html#ga75a647f08ef9df9db7a6ebb9b297add4',1,'libinput.h']]],
  ['libinput_5fevent_5fkeyboard_5fget_5ftime',['libinput_event_keyboard_get_time',['../group__event__keyboard.html#ga0f1a7bb1016816a277b52705d6ef2d71',1,'libinput.h']]],
  ['libinput_5fevent_5fkeyboard_5fget_5ftime_5fusec',['libinput_event_keyboard_get_time_usec',['../group__event__keyboard.html#ga1403b8718219a759fdda0c3944fc9beb',1,'libinput.h']]],
  ['libinput_5fevent_5fkeyboard_5fkey',['LIBINPUT_EVENT_KEYBOARD_KEY',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca477833897722f621bd10bbf3771302d3',1,'libinput.h']]],
  ['libinput_5fevent_5fnone',['LIBINPUT_EVENT_NONE',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7cabccc2f8bdff4e6ff42d3e1318864af67',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer',['libinput_event_pointer',['../structlibinput__event__pointer.html',1,'']]],
  ['libinput_5fevent_5fpointer_5faxis',['LIBINPUT_EVENT_POINTER_AXIS',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca507673764d93c8d46109b069a3ab9bde',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fbutton',['LIBINPUT_EVENT_POINTER_BUTTON',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca26d8ced7a6e63edefb7f72ddd4d1d689',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5fabsolute_5fx',['libinput_event_pointer_get_absolute_x',['../group__event__pointer.html#gac221536b90c7beb70b70b52e710291b5',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5fabsolute_5fx_5ftransformed',['libinput_event_pointer_get_absolute_x_transformed',['../group__event__pointer.html#ga26fa3d0b2bcc7f0a7939b84dc8207021',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5fabsolute_5fy',['libinput_event_pointer_get_absolute_y',['../group__event__pointer.html#ga3e097a9bc6dbbb355fb1982912f72d4c',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5fabsolute_5fy_5ftransformed',['libinput_event_pointer_get_absolute_y_transformed',['../group__event__pointer.html#gaa48effb21f132f05f280859f3d2a9f23',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5faxis_5fsource',['libinput_event_pointer_get_axis_source',['../group__event__pointer.html#ga2116f4bbedb61532e71d16c4f87bd4ca',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5faxis_5fvalue',['libinput_event_pointer_get_axis_value',['../group__event__pointer.html#ga81ad7d8a95c456731a874e584c4c8dda',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5faxis_5fvalue_5fdiscrete',['libinput_event_pointer_get_axis_value_discrete',['../group__event__pointer.html#ga38d12fc6884c9943e261febdb2384b98',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5fbase_5fevent',['libinput_event_pointer_get_base_event',['../group__event__pointer.html#ga4d4f75669001c323dcdc3cc9aec1574a',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5fbutton',['libinput_event_pointer_get_button',['../group__event__pointer.html#ga6dc942e706a29d342a2021afaa49548b',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5fbutton_5fstate',['libinput_event_pointer_get_button_state',['../group__event__pointer.html#ga41e87521ab2a8b7783cb47a63d71da18',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5fdx',['libinput_event_pointer_get_dx',['../group__event__pointer.html#ga29aaf86185a4c9dfa38d98b1fd4dba53',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5fdx_5funaccelerated',['libinput_event_pointer_get_dx_unaccelerated',['../group__event__pointer.html#gad517cc1adc1d43b216804af22499587e',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5fdy',['libinput_event_pointer_get_dy',['../group__event__pointer.html#ga8bb38bb120bbc0ad569c701a6e622612',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5fdy_5funaccelerated',['libinput_event_pointer_get_dy_unaccelerated',['../group__event__pointer.html#ga2a9d66358432b4bee5f8c201f8dc8906',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5fseat_5fbutton_5fcount',['libinput_event_pointer_get_seat_button_count',['../group__event__pointer.html#ga1990b268bdc42ff3277bc43dbb3102ea',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5ftime',['libinput_event_pointer_get_time',['../group__event__pointer.html#gac42d0e19d076f4e1fca15f1ec42510d5',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5ftime_5fusec',['libinput_event_pointer_get_time_usec',['../group__event__pointer.html#gaf0997d730299f40dbe3efcfa06c429be',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fhas_5faxis',['libinput_event_pointer_has_axis',['../group__event__pointer.html#ga1fdd37a49eae958aaf78a0596cd5cef5',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fmotion',['LIBINPUT_EVENT_POINTER_MOTION',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca1812725b7fac7f096cb5d667a6bf89e9',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fmotion_5fabsolute',['LIBINPUT_EVENT_POINTER_MOTION_ABSOLUTE',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca5e277107f22df970e882ef76dd6cc315',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5fpad',['libinput_event_tablet_pad',['../structlibinput__event__tablet__pad.html',1,'']]],
  ['libinput_5fevent_5ftablet_5fpad_5fbutton',['LIBINPUT_EVENT_TABLET_PAD_BUTTON',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca8b1be0a98eba05bd046a15ad32b18a74',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5fpad_5fget_5fbase_5fevent',['libinput_event_tablet_pad_get_base_event',['../group__event__tablet__pad.html#ga33eb585eb7da3f35c083084a1f4e5586',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5fpad_5fget_5fbutton_5fnumber',['libinput_event_tablet_pad_get_button_number',['../group__event__tablet__pad.html#ga4339cf54b0a511599595e8483eea360d',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5fpad_5fget_5fbutton_5fstate',['libinput_event_tablet_pad_get_button_state',['../group__event__tablet__pad.html#ga92235cd641c3003f18c0cb5bbf2e3c88',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5fpad_5fget_5fmode',['libinput_event_tablet_pad_get_mode',['../group__event__tablet__pad.html#ga7ba64faefd071d101d21fd347720ea21',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5fpad_5fget_5fmode_5fgroup',['libinput_event_tablet_pad_get_mode_group',['../group__event__tablet__pad.html#ga154b2b7af0b8913e27d8012530f0aaa3',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5fpad_5fget_5fring_5fnumber',['libinput_event_tablet_pad_get_ring_number',['../group__event__tablet__pad.html#gae866be98b773edcf95ad9a36b5bbacb1',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5fpad_5fget_5fring_5fposition',['libinput_event_tablet_pad_get_ring_position',['../group__event__tablet__pad.html#ga77526f6732ae51aaab3973a69239a25e',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5fpad_5fget_5fring_5fsource',['libinput_event_tablet_pad_get_ring_source',['../group__event__tablet__pad.html#ga96102ae975b4a28f0a02d035dd11496d',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5fpad_5fget_5fstrip_5fnumber',['libinput_event_tablet_pad_get_strip_number',['../group__event__tablet__pad.html#ga32792a10d7f86900a4f94e63037f68b6',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5fpad_5fget_5fstrip_5fposition',['libinput_event_tablet_pad_get_strip_position',['../group__event__tablet__pad.html#gaeff6c2c21b2b02e4d2f9b0b23db27dea',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5fpad_5fget_5fstrip_5fsource',['libinput_event_tablet_pad_get_strip_source',['../group__event__tablet__pad.html#ga9dded037d0f4dbfc9ffa67795118c431',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5fpad_5fget_5ftime',['libinput_event_tablet_pad_get_time',['../group__event__tablet.html#ga126efe81b0c73a14ac71419ee5683f1b',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5fpad_5fget_5ftime_5fusec',['libinput_event_tablet_pad_get_time_usec',['../group__event__tablet__pad.html#ga86dc23306e80986a819e3764a9847108',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5fpad_5fring',['LIBINPUT_EVENT_TABLET_PAD_RING',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca243f5e4a62b72c2ff15d2b025a91e70f',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5fpad_5fstrip',['LIBINPUT_EVENT_TABLET_PAD_STRIP',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca2b66dc7ee62f549a3f63217977a5a306',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool',['libinput_event_tablet_tool',['../structlibinput__event__tablet__tool.html',1,'']]],
  ['libinput_5fevent_5ftablet_5ftool_5faxis',['LIBINPUT_EVENT_TABLET_TOOL_AXIS',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7cafd96baa20189125ce908b3d65a845de1',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fbutton',['LIBINPUT_EVENT_TABLET_TOOL_BUTTON',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca72cb2d7532fb3116debc00d7eecebfa9',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fdistance_5fhas_5fchanged',['libinput_event_tablet_tool_distance_has_changed',['../group__event__tablet.html#ga161c5a254417ed5527beadcdf1bdc55c',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fget_5fbase_5fevent',['libinput_event_tablet_tool_get_base_event',['../group__event__tablet.html#ga90299b56480264cf775c871e52526bb9',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fget_5fbutton',['libinput_event_tablet_tool_get_button',['../group__event__tablet.html#gae36ab2ab73d8b7f00da4cc33f22699ef',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fget_5fbutton_5fstate',['libinput_event_tablet_tool_get_button_state',['../group__event__tablet.html#ga143f62808583b7dddf0a8aa259f71cdb',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fget_5fdistance',['libinput_event_tablet_tool_get_distance',['../group__event__tablet.html#gaae6c3a527a872ef1041d35b0713ed893',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fget_5fdx',['libinput_event_tablet_tool_get_dx',['../group__event__tablet.html#ga868763e264a48cb8df72f5b4724a3c4e',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fget_5fdy',['libinput_event_tablet_tool_get_dy',['../group__event__tablet.html#ga72feb15de8ee3c34a3fa23a78a5c1f3e',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fget_5fpressure',['libinput_event_tablet_tool_get_pressure',['../group__event__tablet.html#gad13f3feea6b9bf599e10e14e96bb9f0b',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fget_5fproximity_5fstate',['libinput_event_tablet_tool_get_proximity_state',['../group__event__tablet.html#ga07823afb37a198173478e029e45ab3ef',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fget_5frotation',['libinput_event_tablet_tool_get_rotation',['../group__event__tablet.html#gae9f1fc19b403e876efd2bd3c3e0b37d6',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fget_5fseat_5fbutton_5fcount',['libinput_event_tablet_tool_get_seat_button_count',['../group__event__tablet.html#ga9dc041db687b59a68e932d0c440af168',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fget_5fslider_5fposition',['libinput_event_tablet_tool_get_slider_position',['../group__event__tablet.html#ga3511bef68bd74deb28f50547f84b0b4d',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fget_5ftilt_5fx',['libinput_event_tablet_tool_get_tilt_x',['../group__event__tablet.html#ga254bf5731441eece5c504c1c95a542c4',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fget_5ftilt_5fy',['libinput_event_tablet_tool_get_tilt_y',['../group__event__tablet.html#ga622aa372b227da77ebb131b183bce9a3',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fget_5ftime',['libinput_event_tablet_tool_get_time',['../group__event__tablet.html#gab35442e0f19101ef200f72c044ab5bbd',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fget_5ftime_5fusec',['libinput_event_tablet_tool_get_time_usec',['../group__event__tablet.html#ga76305fb7651050e33f1bbbc49ec5fb14',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fget_5ftip_5fstate',['libinput_event_tablet_tool_get_tip_state',['../group__event__tablet.html#ga471f9f86ea1de40f036a1ad38bd8dd3a',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fget_5ftool',['libinput_event_tablet_tool_get_tool',['../group__event__tablet.html#gacb4fc9dfc2b370c81f557e6c6f64093a',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fget_5fwheel_5fdelta',['libinput_event_tablet_tool_get_wheel_delta',['../group__event__tablet.html#ga05719a8cb6d74c2f84b7fbfae6036567',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fget_5fwheel_5fdelta_5fdiscrete',['libinput_event_tablet_tool_get_wheel_delta_discrete',['../group__event__tablet.html#gac983a446dab6d1d6835273f2b6110595',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fget_5fx',['libinput_event_tablet_tool_get_x',['../group__event__tablet.html#gab392d487dd9758677066ef8156e7d18c',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fget_5fx_5ftransformed',['libinput_event_tablet_tool_get_x_transformed',['../group__event__tablet.html#ga3b128b24b9fe19a98cb0aaf3624c5ab7',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fget_5fy',['libinput_event_tablet_tool_get_y',['../group__event__tablet.html#gab306166e50d78ece22a1241ba59dfdbc',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fget_5fy_5ftransformed',['libinput_event_tablet_tool_get_y_transformed',['../group__event__tablet.html#ga6c19f3b3679c24f26a46192066f64805',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fpressure_5fhas_5fchanged',['libinput_event_tablet_tool_pressure_has_changed',['../group__event__tablet.html#ga2df1f82b47f641d099f9ccaedfb9240f',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fproximity',['LIBINPUT_EVENT_TABLET_TOOL_PROXIMITY',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca4f726f7db59c83dd948a5ea1d59f57b8',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5frotation_5fhas_5fchanged',['libinput_event_tablet_tool_rotation_has_changed',['../group__event__tablet.html#gad20359ff7caf5869fc00a57fda81a2a7',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fslider_5fhas_5fchanged',['libinput_event_tablet_tool_slider_has_changed',['../group__event__tablet.html#ga50f7af0691ce2196b29ce7715136a2c4',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5ftilt_5fx_5fhas_5fchanged',['libinput_event_tablet_tool_tilt_x_has_changed',['../group__event__tablet.html#gaa640fef5f4211829e3afa9ff60f935a1',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5ftilt_5fy_5fhas_5fchanged',['libinput_event_tablet_tool_tilt_y_has_changed',['../group__event__tablet.html#gaa16d257e4cee353883d39023c0707034',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5ftip',['LIBINPUT_EVENT_TABLET_TOOL_TIP',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca97e12980dafac44aa6b4501e1a6c9a7a',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fwheel_5fhas_5fchanged',['libinput_event_tablet_tool_wheel_has_changed',['../group__event__tablet.html#gaba85fea05184c0d727ed8eb415e17c3f',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fx_5fhas_5fchanged',['libinput_event_tablet_tool_x_has_changed',['../group__event__tablet.html#ga5ccadabe7f75a0639306481ff402058f',1,'libinput.h']]],
  ['libinput_5fevent_5ftablet_5ftool_5fy_5fhas_5fchanged',['libinput_event_tablet_tool_y_has_changed',['../group__event__tablet.html#ga2bbe55e25c7ba2865a958f83175ee877',1,'libinput.h']]],
  ['libinput_5fevent_5ftouch',['libinput_event_touch',['../structlibinput__event__touch.html',1,'']]],
  ['libinput_5fevent_5ftouch_5fcancel',['LIBINPUT_EVENT_TOUCH_CANCEL',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7caaf4ed8adce078146aedac569e3178052',1,'libinput.h']]],
  ['libinput_5fevent_5ftouch_5fdown',['LIBINPUT_EVENT_TOUCH_DOWN',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7caa14993972db3e944b4e3f5e74dd99dcb',1,'libinput.h']]],
  ['libinput_5fevent_5ftouch_5fframe',['LIBINPUT_EVENT_TOUCH_FRAME',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca2b9b566a3bf1f460a144456697ee7387',1,'libinput.h']]],
  ['libinput_5fevent_5ftouch_5fget_5fbase_5fevent',['libinput_event_touch_get_base_event',['../group__event__touch.html#gacb2cd144a719c9873cd4621db278e92c',1,'libinput.h']]],
  ['libinput_5fevent_5ftouch_5fget_5fseat_5fslot',['libinput_event_touch_get_seat_slot',['../group__event__touch.html#gabac75c78a0a360995e1a521edb38c4da',1,'libinput.h']]],
  ['libinput_5fevent_5ftouch_5fget_5fslot',['libinput_event_touch_get_slot',['../group__event__touch.html#gaf5294eab86b9125b7fb607049ff9ef09',1,'libinput.h']]],
  ['libinput_5fevent_5ftouch_5fget_5ftime',['libinput_event_touch_get_time',['../group__event__touch.html#ga5d13da5020c6aff78604943690f8cbe9',1,'libinput.h']]],
  ['libinput_5fevent_5ftouch_5fget_5ftime_5fusec',['libinput_event_touch_get_time_usec',['../group__event__touch.html#ga83cc90b988d15037c438f5c457feab5e',1,'libinput.h']]],
  ['libinput_5fevent_5ftouch_5fget_5fx',['libinput_event_touch_get_x',['../group__event__touch.html#gac42d0e070811c360cf8ec784349954ba',1,'libinput.h']]],
  ['libinput_5fevent_5ftouch_5fget_5fx_5ftransformed',['libinput_event_touch_get_x_transformed',['../group__event__touch.html#gadd04ccc3a7b4564e5aca3c8592f090fe',1,'libinput.h']]],
  ['libinput_5fevent_5ftouch_5fget_5fy',['libinput_event_touch_get_y',['../group__event__touch.html#ga30711113bcef4bc02eda7878a054351c',1,'libinput.h']]],
  ['libinput_5fevent_5ftouch_5fget_5fy_5ftransformed',['libinput_event_touch_get_y_transformed',['../group__event__touch.html#ga36af95f47b6d69b581eaeee69927af6f',1,'libinput.h']]],
  ['libinput_5fevent_5ftouch_5fmotion',['LIBINPUT_EVENT_TOUCH_MOTION',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7caa96855d3716c4dccd47a69753ed2d468',1,'libinput.h']]],
  ['libinput_5fevent_5ftouch_5fup',['LIBINPUT_EVENT_TOUCH_UP',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca1b48aaefbee80a1cbbcb5986d650bc62',1,'libinput.h']]],
  ['libinput_5fevent_5ftype',['libinput_event_type',['../group__base.html#gac30276a06e8b1434b959f2c8dde74f7c',1,'libinput.h']]],
  ['libinput_5fget_5fevent',['libinput_get_event',['../group__base.html#gacead6670eaecf7c807659e2b6c725630',1,'libinput.h']]],
  ['libinput_5fget_5ffd',['libinput_get_fd',['../group__base.html#ga885a59371d4e8de0e18a2a2a66942e11',1,'libinput.h']]],
  ['libinput_5fget_5fuser_5fdata',['libinput_get_user_data',['../group__base.html#ga3eab49413b8430c2eee987a39f4a410b',1,'libinput.h']]],
  ['libinput_5finterface',['libinput_interface',['../structlibinput__interface.html',1,'']]],
  ['libinput_5fkey_5fstate',['libinput_key_state',['../group__device.html#ga360bdea89a75606472a0b5d72678bd17',1,'libinput.h']]],
  ['libinput_5fkey_5fstate_5fpressed',['LIBINPUT_KEY_STATE_PRESSED',['../group__device.html#gga360bdea89a75606472a0b5d72678bd17a3fa7cb12e694a4b1310f6df77e93d46e',1,'libinput.h']]],
  ['libinput_5fkey_5fstate_5freleased',['LIBINPUT_KEY_STATE_RELEASED',['../group__device.html#gga360bdea89a75606472a0b5d72678bd17a40f08dfe7bf96603f75bba186721992c',1,'libinput.h']]],
  ['libinput_5fled',['libinput_led',['../group__device.html#ga37ec9afaec2e5407e3c5248faedd1970',1,'libinput.h']]],
  ['libinput_5fled_5fcaps_5flock',['LIBINPUT_LED_CAPS_LOCK',['../group__device.html#gga37ec9afaec2e5407e3c5248faedd1970a10cf3c49445b0baf5e91590391e59ebe',1,'libinput.h']]],
  ['libinput_5fled_5fnum_5flock',['LIBINPUT_LED_NUM_LOCK',['../group__device.html#gga37ec9afaec2e5407e3c5248faedd1970aa82d6090fb4615d2379f59c06c79588a',1,'libinput.h']]],
  ['libinput_5fled_5fscroll_5flock',['LIBINPUT_LED_SCROLL_LOCK',['../group__device.html#gga37ec9afaec2e5407e3c5248faedd1970a1914ddccb1739d77543767d7768e3abd',1,'libinput.h']]],
  ['libinput_5flog_5fget_5fpriority',['libinput_log_get_priority',['../group__base.html#ga7367998ca39a6e873920ba5e2a12d4f0',1,'libinput.h']]],
  ['libinput_5flog_5fhandler',['libinput_log_handler',['../group__base.html#gaa16223d9fa8b6e3ac7c722e184f2217f',1,'libinput.h']]],
  ['libinput_5flog_5fpriority',['libinput_log_priority',['../group__base.html#gaa7e9ebbd1a13fe2ed6f44e69df3216e1',1,'libinput.h']]],
  ['libinput_5flog_5fpriority_5fdebug',['LIBINPUT_LOG_PRIORITY_DEBUG',['../group__base.html#ggaa7e9ebbd1a13fe2ed6f44e69df3216e1a3f46e5b7430e100479b4ea27f0fbb1f8',1,'libinput.h']]],
  ['libinput_5flog_5fpriority_5ferror',['LIBINPUT_LOG_PRIORITY_ERROR',['../group__base.html#ggaa7e9ebbd1a13fe2ed6f44e69df3216e1ad79f66fcf1d6cbd03678cfc5b012b83d',1,'libinput.h']]],
  ['libinput_5flog_5fpriority_5finfo',['LIBINPUT_LOG_PRIORITY_INFO',['../group__base.html#ggaa7e9ebbd1a13fe2ed6f44e69df3216e1a9b457be58d6cf5d66ea177aa3d2c5500',1,'libinput.h']]],
  ['libinput_5flog_5fset_5fhandler',['libinput_log_set_handler',['../group__base.html#gacf00228a43c831817ba6ec0b94b9df74',1,'libinput.h']]],
  ['libinput_5flog_5fset_5fpriority',['libinput_log_set_priority',['../group__base.html#ga75a500c54c61cfcecd4c76dbb8022933',1,'libinput.h']]],
  ['libinput_5fnext_5fevent_5ftype',['libinput_next_event_type',['../group__base.html#gac86ad3c0c5bc27d8f630264f46cdf005',1,'libinput.h']]],
  ['libinput_5fpath_5fadd_5fdevice',['libinput_path_add_device',['../group__base.html#gaa797496f0150b482a4e01376bd33a47b',1,'libinput.h']]],
  ['libinput_5fpath_5fcreate_5fcontext',['libinput_path_create_context',['../group__base.html#ga363c6b6e47dcf410a3b3ebd5547c8b07',1,'libinput.h']]],
  ['libinput_5fpath_5fremove_5fdevice',['libinput_path_remove_device',['../group__base.html#ga9cb53cdcce2c000001ac17706a612121',1,'libinput.h']]],
  ['libinput_5fpointer_5faxis',['libinput_pointer_axis',['../group__device.html#ga82cd15b9476a4a60f25470df8d67483c',1,'libinput.h']]],
  ['libinput_5fpointer_5faxis_5fscroll_5fhorizontal',['LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL',['../group__device.html#gga82cd15b9476a4a60f25470df8d67483caf0618a16f29ca56a8df0b624442f9852',1,'libinput.h']]],
  ['libinput_5fpointer_5faxis_5fscroll_5fvertical',['LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL',['../group__device.html#gga82cd15b9476a4a60f25470df8d67483ca538dfb7d4ab598030af4d57aac55a1e5',1,'libinput.h']]],
  ['libinput_5fpointer_5faxis_5fsource',['libinput_pointer_axis_source',['../group__device.html#ga76c012d8f6d7656fb795dc7bdf9d6551',1,'libinput.h']]],
  ['libinput_5fpointer_5faxis_5fsource_5fcontinuous',['LIBINPUT_POINTER_AXIS_SOURCE_CONTINUOUS',['../group__device.html#gga76c012d8f6d7656fb795dc7bdf9d6551a3843fac25b1895de1d05191daf4527f6',1,'libinput.h']]],
  ['libinput_5fpointer_5faxis_5fsource_5ffinger',['LIBINPUT_POINTER_AXIS_SOURCE_FINGER',['../group__device.html#gga76c012d8f6d7656fb795dc7bdf9d6551a6a55790b11ef0aaecb897329d29a9fbb',1,'libinput.h']]],
  ['libinput_5fpointer_5faxis_5fsource_5fwheel',['LIBINPUT_POINTER_AXIS_SOURCE_WHEEL',['../group__device.html#gga76c012d8f6d7656fb795dc7bdf9d6551a60e7f4a41ceda06fe3eba2d512dc8ec9',1,'libinput.h']]],
  ['libinput_5fref',['libinput_ref',['../group__base.html#gafff29392ec52e1e7de5bb812e085127a',1,'libinput.h']]],
  ['libinput_5fresume',['libinput_resume',['../group__base.html#ga5a1ee92fa05df27e3c0f37d524cc17a6',1,'libinput.h']]],
  ['libinput_5fseat',['libinput_seat',['../structlibinput__seat.html',1,'']]],
  ['libinput_5fseat_5fget_5fcontext',['libinput_seat_get_context',['../group__seat.html#ga634ac38cf583d1da4e99824860d91efc',1,'libinput.h']]],
  ['libinput_5fseat_5fget_5flogical_5fname',['libinput_seat_get_logical_name',['../group__seat.html#ga61e477120d5f0cc67a06d04575186948',1,'libinput.h']]],
  ['libinput_5fseat_5fget_5fphysical_5fname',['libinput_seat_get_physical_name',['../group__seat.html#gac881036869846ad87eb7814fbf308251',1,'libinput.h']]],
  ['libinput_5fseat_5fget_5fuser_5fdata',['libinput_seat_get_user_data',['../group__seat.html#gac7af04e67fc803f1f7756d02e5372e91',1,'libinput.h']]],
  ['libinput_5fseat_5fref',['libinput_seat_ref',['../group__seat.html#ga60445ab81e8ee3a10b85e88617231069',1,'libinput.h']]],
  ['libinput_5fseat_5fset_5fuser_5fdata',['libinput_seat_set_user_data',['../group__seat.html#ga669ed8a095445e9537deef8a9880587b',1,'libinput.h']]],
  ['libinput_5fseat_5funref',['libinput_seat_unref',['../group__seat.html#ga81d52d0e9332f07c39a899c8c2fd3400',1,'libinput.h']]],
  ['libinput_5fset_5fuser_5fdata',['libinput_set_user_data',['../group__base.html#gac1a020ab0a0da92749e24e80538ab28f',1,'libinput.h']]],
  ['libinput_5fsuspend',['libinput_suspend',['../group__base.html#ga60662dc666f6188dc207467c9d8e99ab',1,'libinput.h']]],
  ['libinput_5ftablet_5fpad_5fmode_5fgroup',['libinput_tablet_pad_mode_group',['../structlibinput__tablet__pad__mode__group.html',1,'']]],
  ['libinput_5ftablet_5fpad_5fmode_5fgroup_5fbutton_5fis_5ftoggle',['libinput_tablet_pad_mode_group_button_is_toggle',['../group__tablet__pad__modes.html#gade239729d9a9449513cd46f8b9e00ba5',1,'libinput.h']]],
  ['libinput_5ftablet_5fpad_5fmode_5fgroup_5fget_5findex',['libinput_tablet_pad_mode_group_get_index',['../group__tablet__pad__modes.html#ga6aafbf3c20d52ea0a4490e7841ee90ba',1,'libinput.h']]],
  ['libinput_5ftablet_5fpad_5fmode_5fgroup_5fget_5fmode',['libinput_tablet_pad_mode_group_get_mode',['../group__tablet__pad__modes.html#ga6665cafeed47b6b061c702760e7654a5',1,'libinput.h']]],
  ['libinput_5ftablet_5fpad_5fmode_5fgroup_5fget_5fnum_5fmodes',['libinput_tablet_pad_mode_group_get_num_modes',['../group__tablet__pad__modes.html#ga63f52e1cdcde522fe6990e4407782d4b',1,'libinput.h']]],
  ['libinput_5ftablet_5fpad_5fmode_5fgroup_5fget_5fuser_5fdata',['libinput_tablet_pad_mode_group_get_user_data',['../group__tablet__pad__modes.html#ga1b78ddbdbe034594f86bf26dca5dd13c',1,'libinput.h']]],
  ['libinput_5ftablet_5fpad_5fmode_5fgroup_5fhas_5fbutton',['libinput_tablet_pad_mode_group_has_button',['../group__tablet__pad__modes.html#ga6e6efcb715243ec826023071a9271c81',1,'libinput.h']]],
  ['libinput_5ftablet_5fpad_5fmode_5fgroup_5fhas_5fring',['libinput_tablet_pad_mode_group_has_ring',['../group__tablet__pad__modes.html#ga22a228d4e60c38c5d57578291f0947aa',1,'libinput.h']]],
  ['libinput_5ftablet_5fpad_5fmode_5fgroup_5fhas_5fstrip',['libinput_tablet_pad_mode_group_has_strip',['../group__tablet__pad__modes.html#ga54c2c799139404a00a18d1dda1c7d3c9',1,'libinput.h']]],
  ['libinput_5ftablet_5fpad_5fmode_5fgroup_5fref',['libinput_tablet_pad_mode_group_ref',['../group__tablet__pad__modes.html#ga24f9fe4abfed860c6fd9dbd6963df79b',1,'libinput.h']]],
  ['libinput_5ftablet_5fpad_5fmode_5fgroup_5fset_5fuser_5fdata',['libinput_tablet_pad_mode_group_set_user_data',['../group__tablet__pad__modes.html#ga321255fc232405a48569a631444b0f69',1,'libinput.h']]],
  ['libinput_5ftablet_5fpad_5fmode_5fgroup_5funref',['libinput_tablet_pad_mode_group_unref',['../group__tablet__pad__modes.html#ga486ea28bdecd75500916367972d6bfe7',1,'libinput.h']]],
  ['libinput_5ftablet_5fpad_5fring_5faxis_5fsource',['libinput_tablet_pad_ring_axis_source',['../group__event__tablet__pad.html#gafb0259f1d3f79e4ecaa74eb307186473',1,'libinput.h']]],
  ['libinput_5ftablet_5fpad_5fring_5fsource_5ffinger',['LIBINPUT_TABLET_PAD_RING_SOURCE_FINGER',['../group__event__tablet__pad.html#ggafb0259f1d3f79e4ecaa74eb307186473acf6148ddec89e3307ab0df053da1e96f',1,'libinput.h']]],
  ['libinput_5ftablet_5fpad_5fring_5fsource_5funknown',['LIBINPUT_TABLET_PAD_RING_SOURCE_UNKNOWN',['../group__event__tablet__pad.html#ggafb0259f1d3f79e4ecaa74eb307186473a0a973dc16228d89efd0ef5995b0e5881',1,'libinput.h']]],
  ['libinput_5ftablet_5fpad_5fstrip_5faxis_5fsource',['libinput_tablet_pad_strip_axis_source',['../group__event__tablet__pad.html#ga09790bd108d3a288bb387aeb3a9a2dd8',1,'libinput.h']]],
  ['libinput_5ftablet_5fpad_5fstrip_5fsource_5ffinger',['LIBINPUT_TABLET_PAD_STRIP_SOURCE_FINGER',['../group__event__tablet__pad.html#gga09790bd108d3a288bb387aeb3a9a2dd8add543fc4601c82698d588892bc9c9de8',1,'libinput.h']]],
  ['libinput_5ftablet_5fpad_5fstrip_5fsource_5funknown',['LIBINPUT_TABLET_PAD_STRIP_SOURCE_UNKNOWN',['../group__event__tablet__pad.html#gga09790bd108d3a288bb387aeb3a9a2dd8a5ed957a8e351e24e8b1efe7361694a74',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool',['libinput_tablet_tool',['../structlibinput__tablet__tool.html',1,'']]],
  ['libinput_5ftablet_5ftool_5fget_5fserial',['libinput_tablet_tool_get_serial',['../group__event__tablet.html#gac8084f1e2891ccaa9be5faedf4310f78',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool_5fget_5ftool_5fid',['libinput_tablet_tool_get_tool_id',['../group__event__tablet.html#ga5ba26a193ce809fab9234b2253bcfff8',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool_5fget_5ftype',['libinput_tablet_tool_get_type',['../group__event__tablet.html#ga879d814a10261d8f379dc26d2789bfa8',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool_5fget_5fuser_5fdata',['libinput_tablet_tool_get_user_data',['../group__event__tablet.html#gad5e4615494fe6a18d36d7819f4101a9e',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool_5fhas_5fbutton',['libinput_tablet_tool_has_button',['../group__event__tablet.html#gac6caf390be962bbe330e30d61cc24a82',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool_5fhas_5fdistance',['libinput_tablet_tool_has_distance',['../group__event__tablet.html#ga6e20b30e6e6cbddbf2cc159b5d6b7046',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool_5fhas_5fpressure',['libinput_tablet_tool_has_pressure',['../group__event__tablet.html#gaa4fa6ae9a0c4f9212a28dbd50ee54af3',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool_5fhas_5frotation',['libinput_tablet_tool_has_rotation',['../group__event__tablet.html#gaab7bcd835ac261f8baace7a1f2f3b26d',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool_5fhas_5fslider',['libinput_tablet_tool_has_slider',['../group__event__tablet.html#gae004c5b3a2553ea58673871f69d46a36',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool_5fhas_5ftilt',['libinput_tablet_tool_has_tilt',['../group__event__tablet.html#gac5470ae95d36cc733f5a9167c087f8d1',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool_5fhas_5fwheel',['libinput_tablet_tool_has_wheel',['../group__event__tablet.html#gaca9317e6ba30236004b183922270cf67',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool_5fis_5funique',['libinput_tablet_tool_is_unique',['../group__event__tablet.html#ga22aff11d12f9f4541cc2a8152da62207',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool_5fproximity_5fstate',['libinput_tablet_tool_proximity_state',['../group__device.html#ga54f9b346c0338de742583a8e7c2b0628',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool_5fproximity_5fstate_5fin',['LIBINPUT_TABLET_TOOL_PROXIMITY_STATE_IN',['../group__device.html#gga54f9b346c0338de742583a8e7c2b0628a90e9036c5474e8d5675549ceadcbd5f2',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool_5fproximity_5fstate_5fout',['LIBINPUT_TABLET_TOOL_PROXIMITY_STATE_OUT',['../group__device.html#gga54f9b346c0338de742583a8e7c2b0628aca836e7d6fb61219ba4627ccaf0b47f8',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool_5fref',['libinput_tablet_tool_ref',['../group__event__tablet.html#ga3590fb3c4c03fcfbd2171e6f012a755d',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool_5fset_5fuser_5fdata',['libinput_tablet_tool_set_user_data',['../group__event__tablet.html#gac875c430f43dbf53c10c6884e2808338',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool_5ftip_5fdown',['LIBINPUT_TABLET_TOOL_TIP_DOWN',['../group__device.html#ggabc8383829ae67efea5543fb8af117091a5d3293f81d157a683b614ba98605a419',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool_5ftip_5fstate',['libinput_tablet_tool_tip_state',['../group__device.html#gabc8383829ae67efea5543fb8af117091',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool_5ftip_5fup',['LIBINPUT_TABLET_TOOL_TIP_UP',['../group__device.html#ggabc8383829ae67efea5543fb8af117091aeeb7a764816c32a910bbdb14314ba613',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool_5ftype',['libinput_tablet_tool_type',['../group__device.html#ga8348e628baa2646d31abf0fe7245924f',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool_5ftype_5fairbrush',['LIBINPUT_TABLET_TOOL_TYPE_AIRBRUSH',['../group__device.html#gga8348e628baa2646d31abf0fe7245924fa34519f7fadd32713f2383e6142016bb3',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool_5ftype_5fbrush',['LIBINPUT_TABLET_TOOL_TYPE_BRUSH',['../group__device.html#gga8348e628baa2646d31abf0fe7245924fad4a91e99e064f8172bd2ab8310c106d0',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool_5ftype_5feraser',['LIBINPUT_TABLET_TOOL_TYPE_ERASER',['../group__device.html#gga8348e628baa2646d31abf0fe7245924fa69812dd85e9d5b6775ecaf52ece3c19f',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool_5ftype_5flens',['LIBINPUT_TABLET_TOOL_TYPE_LENS',['../group__device.html#gga8348e628baa2646d31abf0fe7245924fa56a0427909230244aeedad4e48b0384c',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool_5ftype_5fmouse',['LIBINPUT_TABLET_TOOL_TYPE_MOUSE',['../group__device.html#gga8348e628baa2646d31abf0fe7245924fa2544090800eca843af88bb2cf383e92e',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool_5ftype_5fpen',['LIBINPUT_TABLET_TOOL_TYPE_PEN',['../group__device.html#gga8348e628baa2646d31abf0fe7245924fa9a76daea205049e4b71b0c30bb203436',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool_5ftype_5fpencil',['LIBINPUT_TABLET_TOOL_TYPE_PENCIL',['../group__device.html#gga8348e628baa2646d31abf0fe7245924faec53813f855d7009fb1476c4a95990c6',1,'libinput.h']]],
  ['libinput_5ftablet_5ftool_5funref',['libinput_tablet_tool_unref',['../group__event__tablet.html#ga10577ff3acd02131ceb8cd7d5e4469ee',1,'libinput.h']]],
  ['libinput_5fudev_5fassign_5fseat',['libinput_udev_assign_seat',['../group__base.html#ga71a60660b30cb476495e75766222d144',1,'libinput.h']]],
  ['libinput_5fudev_5fcreate_5fcontext',['libinput_udev_create_context',['../group__base.html#ga7512ea602d4b259085c47f6374b078d1',1,'libinput.h']]],
  ['libinput_5funref',['libinput_unref',['../group__base.html#ga7ed0797d23e34b650e0aeb98b5350309',1,'libinput.h']]],
  ['lenovo_20_2a40_20series_20touchpad_20support',['Lenovo *40 series touchpad support',['../t440_support.html',1,'touchpads']]],
  ['libinput_20test_20suite',['libinput test suite',['../test-suite.html',1,'developers']]]
];
